/**********************************************************
***********************************************************
*               European Southern Observatory
*               VLTI Data Reduction Software
*
* Module name:  diagnostics.h
* Description:
*
*
* History:
* 08-Jan-04     (csabet) Created
***********************************************************
**********************************************************/
#ifndef _DIAGNOSTICS_H
#define _DIAGNOSTICS_H

/**********************************************************
*   Include files
**********************************************************/
#include "midiLib.h"

/**********************************************************
*   Constant definitions
**********************************************************/

/**********************************************************
*   Global Variables
**********************************************************/

/**********************************************************
*   Type definitions
**********************************************************/
void reportRejectList (
    ImageFormat		*format,
	CompressedData	*compressed);

void midiCreatePlotFileDouble2D2P (
	const char	*plotFileName,
	const char	*title,
	const char	*xLabel,
	const char	*yLabel,
	int		deletePlot,
	double	*arrayX,
	double	*arrayY,
	int		begin,
	int		end,
    int		interval,
	const char	*lineType);

void midiCreatePlotFileDouble2D (
	const char	*plotFileName,
	const char	*title,
	const char	*xLabel,
	const char	*yLabel,
	int		deletePlot,
	double	*array,
	int		begin,
	int		end,
    int		interval);

void midiCreateReplotFileDouble2D2P (
	char	*plotFileName,
	char	*title,
	char	*xLabel,
	char	*yLabel,
	int		deletePlot,
	double	*arrayX,
	double	*arrayY,
	int		begin,
	int		end,
    int		interval,
	char	*lineType);

void midiCreatePlotFileDouble3D (
	const char	*plotFileName,
	const char	*title,
	const char	*xLabel,
	const char	*yLabel,
	const char	*zLabel,
	int		deletePlot,
	double	*image,
	int		sizeX,
	int		sizeY,
	const char	*style,
	const char	*lineType);

void midiCreatePlotFile2D2P (
	const char	*plotFileName,
	const char	*title,
	const char	*xLabel,
	const char	*yLabel,
	int		deletePlot,
	float	*arrayX,
	float	*arrayY,
	int		begin,
	int		end,
    int		interval);

void midiCreatePlotFile2D (
	const char	*plotFileName,
	const char	*title,
	const char	*xLabel,
	const char	*yLabel,
	int		deletePlot,
	float	*array,
	int		begin,
	int		end,
    int		interval,
    int		override);

void midiCreatePlotFile3D (
	const char	*plotFileName,
	const char	*title,
	const char	*xLabel,
	const char	*yLabel,
	const char	*zLabel,
	int		deletePlot,
	float	*image,
	int		sizeX,
	int		sizeY,
	const char	*style,
	const char	*lineType);

void getVersions (void);

void prepareWaterfallDisplay (
    MidiFiles		*fileNames,
    ImageFormat		*imageSize,
	CompressedData	*compressed);

void prepareWaterpowerDisplay (
    MidiFiles	*filenames,
    ImageFormat	*imageFormat,
    float		*allSpectrum);

void reportInterfChopping (
	const char			*dataKey,
	ImageFormat		*format,
	CompressedData	*compressed);

void reportPhotomChopping (
	const char			*dataKey,
	ImageFormat		*format,
	CompressedData	*compressed);

int countTransitions (
	char	key,
    int		length,
    char	*tarType);

void displayPhotomChoppingDisp (
	const char			*dataKey,
	ImageFormat		*format,
	CompressedData	*compressed);

void displayInterfChoppingDisp (
	const char			*dataKey,
	ImageFormat		*format,
	CompressedData	*compressed);

void midiReportResultsFringe (
	float   		*freqCal,
    ImageFormat		*format,
	DispersedResult	*dispResult);

/*********************************************************/
/*********************************************************/
#endif
